@@ -42,6 +42,13 @@ class TestDumpLoad(unittest.TestCase):
         assert load(dump(EnumA.C), EnumA) == EnumA.C
 
 
+class TestLegacyDump(unittest.TestCase):
+
+    def test_dump(self):
+        A = NamedTuple('A',[('a', int), ('b', str)])
+        assert dump(A(1, '12')) == {'a': 1, 'b': '12'}
+
+
 class TestBasicDump(unittest.TestCase):
 
     def test_dump_namedtuple(self):
@@ -81,3 +88,26 @@ class TestBasicDump(unittest.TestCase):
         with self.assertRaises(ValueError):
             assert dumper.dump(None) == None
             assert dumper.dump(True) == True
+
+
+class TestHandlers(unittest.TestCase):
+
+    def test_custom_handler(self):
+        class Q:
+            def __eq__(self, other):
+                return isinstance(other, Q)
+
+        dumper = datadumper.Dumper()
+        dumper.handlers.append((
+            lambda v: isinstance(v, Q),
+            lambda l, v: 12
+        ))
+        assert dumper.dump(Q()) == 12
+
+    def test_broken_handler(self):
+        dumper = datadumper.Dumper()
+        dumper.handlers.insert(0, (lambda v: 'a' + v is None, lambda l, v: None))
+        with self.assertRaises(TypeError):
+            dumper.dump(1)
+        dumper.raiseconditionerrors = False
+        assert dumper.dump(1) == 1
