@@ -90,3 +90,27 @@ def dump(value: Any) -> Any:
     from . import datadumper
     dumper = datadumper.Dumper()
     return dumper.dump(value)
+
+
+def attrload(value: Any, type_: Type[T]) -> T:
+    """
+    Quick function call to load data supporting the attr module
+    in addition to the default ones.
+    """
+    from . import dataloader
+    from .plugins import attrload as loadplugin
+    loader = dataloader.Loader()
+    loadplugin.add2loader(loader)
+    return loader.load(value, type_)
+
+
+def attrdump(value: Any) -> Any:
+    """
+    Quick function to do a dump that supports the attr
+    module.
+    """
+    from . import datadumper
+    from .plugins import attrdump as dumpplugin
+    dumper = datadumper.Dumper()
+    dumpplugin.add2dumper(dumper)
+    return dumper.dump(value)
